lfs_object_from_path

Function lfs_object_from_path 

pub fn lfs_object_from_path(path: &str) -> Option<(String, String)>
Split an LFS object path (<repo>/info/lfs/objects/<oid>) into (repo, oid). Any query string must be stripped by the caller. None if the path is not an object request or the oid is malformed.