HTTP surface: the git smart-HTTP endpoints plus health/metrics.
Routing is method + path suffix based (git paths have arbitrary depth), so
the git handler is registered as the router fallback and dispatches:
GET
HTTP surface: the git smart-HTTP endpoints plus health/metrics.
Routing is method + path suffix based (git paths have arbitrary depth), so
the git handler is registered as the router fallback and dispatches:
GET